# APIリファレンス

Wandasライブラリの主要コンポーネントと関数のAPIリファレンスです。

## コアモジュール

コアモジュールはWandasの基本的な機能を提供します。

::: wandas.core

## フレームモジュール

フレームモジュールは異なるタイプのデータフレームを定義します。

::: wandas.frames

## 処理モジュール

処理モジュールはオーディオデータに対する様々な処理機能を提供します。

::: wandas.processing

## 入出力モジュール

入出力モジュールはファイルの読み書き機能を提供します。

::: wandas.io

## ユーティリティモジュール

ユーティリティモジュールは補助機能を提供します。

::: wandas.utils

## 可視化モジュール

可視化モジュールはデータの視覚化機能を提供します。

::: wandas.visualization

## データセットモジュール

データセットモジュールはサンプルデータとデータセット機能を提供します。

::: wandas.datasets
